**Contribution License Agreement**

This Contribution License Agreement (**“Agreement”**) is agreed to by the party signing below (**“You”**),

and conveys certain license rights to NVIDIA Corporation and its affiliates (**“NVIDIA”**) for Your

contributions to NVIDIA open source projects. This Agreement is effective as of the latest signature

date below.

**1\. Definitions.**

**“Code”** means the computer software code, whether in human-readable or machine-executable form,

that is delivered by You to NVIDIA under this Agreement.

**“Project”** means any of the projects owned or managed by NVIDIA in which software is offered under

a license approved by the Open Source Initiative (OSI) (<www.opensource.org>) and documentation

offered under an OSI or a Creative Commons license (<https://creativecommons.org/licenses>).

**“Submit”** is the act of uploading, submitting, transmitting, or distributing code or other content to any

Project, including but not limited to communication on electronic mailing lists, source code control

systems, and issue tracking systems that are managed by, or on behalf of, the Project for the purpose of

discussing and improving that Project, but excluding communication that is conspicuously marked or

otherwise designated in writing by You as “Not a Submission.”

**“Submission”** means the Code and any other copyrightable material Submitted by You, including any

associated comments and documentation.

**2\. Your Submission.** You must agree to the terms of this Agreement before making a Submission to any

Project. This Agreement covers any and all Submissions that You, now or in the future (except as

described in Section 4 below), Submit to any Project.

**3\. Originality of Work**. You represent that each of Your Submissions is entirely Your original work.

Should You wish to Submit materials that are not Your original work, You may Submit them separately

to the Project if You (a) retain all copyright and license information that was in the materials as You

received them, (b) in the description accompanying Your Submission, include the phrase “Submission

containing materials of a third party:” followed by the names of the third party and any licenses or other

restrictions of which You are aware, and (c) follow any other instructions in the Project’s written

guidelines concerning Submissions.

**4\. Your Employer.** References to “employer” in this Agreement include Your employer or anyone else

for whom You are acting in making Your Submission, e.g. as a contractor, vendor, or agent. If Your

Submission is made in the course of Your work for an employer or Your employer has intellectual

property rights in Your Submission by contract or applicable law, You must secure permission from Your

employer to make the Submission before signing this Agreement. In that case, the term “You” in this

Agreement will refer to You and the employer collectively. If You change employers in the future and

desire to Submit additional Submissions for the new employer, then You agree to sign a new Agreement

and secure permission from the new employer before Submitting those Submissions.

**5\. Licenses.**

**a. Copyright License.** You grant NVIDIA, and those who receive the Submission directly or

indirectly from NVIDIA, a perpetual, worldwide, non-exclusive, royalty-free, irrevocable license in the

Submission to reproduce, prepare derivative works of, publicly display, publicly perform, and distribute

the Submission and such derivative works, and to sublicense any or all of the foregoing rights to third

parties.

**b. Patent License.** You grant NVIDIA, and those who receive the Submission directly or

indirectly from NVIDIA, a perpetual, worldwide, non-exclusive, royalty-free, irrevocable license under

Your patent claims that are necessarily infringed by the Submission or the combination of the

Submission with the Project to which it was Submitted to make, have made, use, offer to sell, sell and

import or otherwise dispose of the Submission alone or with the Project.

**c. Other Rights Reserved.** Each party reserves all rights not expressly granted in this Agreement.

No additional licenses or rights whatsoever (including, without limitation, any implied licenses) are

granted by implication, exhaustion, estoppel or otherwise.

**6\. Representations and Warranties.** You represent that You are legally entitled to grant the above

licenses. You represent that each of Your Submissions is entirely Your original work (except as You may

have disclosed under Section 3). You represent that You have secured permission from Your employer to

make the Submission in cases where Your Submission is made in the course of Your work for Your

employer or Your employer has intellectual property rights in Your Submission by contract or applicable

law. If You are signing this Agreement on behalf of Your employer, You represent and warrant that You

have the necessary authority to bind the listed employer to the obligations contained in this Agreement.

You are not expected to provide support for Your Submission, unless You choose to do so. UNLESS

REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING, AND EXCEPT FOR THE WARRANTIES

EXPRESSLY STATED IN SECTIONS 3, 4, AND 6, THE SUBMISSION PROVIDED UNDER THIS AGREEMENT IS

PROVIDED WITHOUT WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, ANY WARRANTY OF

NONINFRINGEMENT, MERCHANTABILITY, OR FITNESS FOR A PARTICULAR PURPOSE.

**7\. Notice to NVIDIA.** You agree to notify NVIDIA in writing of any facts or circumstances of which

You later become aware that would make Your representations in this Agreement inaccurate in any

respect.

**8\. Information about Submissions.** You agree that contributions to Projects and information about

contributions may be maintained indefinitely and disclosed publicly, including Your name and other

information that You submit with Your Submission.

**9\. Governing Law/Jurisdiction.** Claims arising under this Agreement shall be governed by the laws of Delaware, excluding its principles of conflict of laws and the United Nations Convention on Contracts for the Sale of Goods. The state and/or federal courts residing in Santa Clara County, California shall have exclusive jurisdiction over any dispute or claim arising out of this Agreement. You may not export the Software in violation of applicable export laws and regulations.

**10\. Entire Agreement/Assignment.** This Agreement is the entire agreement between the parties, and

supersedes any and all prior agreements, understandings or communications, written or oral, between

the parties relating to the subject matter hereof. This Agreement may be assigned by NVIDIA.

Please select one of the options below and sign as indicated. By signing, You accept and agree to the

terms of this Contribution License Agreement for Your present and future Submissions to NVIDIA.

\___ I have sole ownership of intellectual property rights to my Submissions and I am not making

Submissions in the course of work for my employer.

Name (“You”): \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

Signature: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

Date: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

GitHub Login: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

Email: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

Address: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

\___ I am making Submissions in the course of work for my employer (or my employer has intellectual

property rights in my Submissions by contract or applicable law). I have permission from my

employer to make Submissions and enter into this Agreement on behalf of my employer. By signing

below, the defined term “You” includes me and my employer.

Company Name: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

Signature: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

By: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

Title: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

Date: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

GitHub Login: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

Email: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__

Address: \_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\_**\___\__